ardt.datasets.MultiDataset
==========================

.. currentmodule:: ardt.datasets

.. autoclass:: MultiDataset

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~MultiDataset.__init__
      ~MultiDataset.get_media_name_by_movie_id
      ~MultiDataset.get_signal_metadata
      ~MultiDataset.get_trial_splits
      ~MultiDataset.get_working_dir
      ~MultiDataset.get_working_path
      ~MultiDataset.load_trials
      ~MultiDataset.preload
      ~MultiDataset.set_signal_metadata
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~MultiDataset.expected_media_responses
      ~MultiDataset.media_file_offset
      ~MultiDataset.media_ids
      ~MultiDataset.media_names_by_movie_id
      ~MultiDataset.participant_ids
      ~MultiDataset.participant_offset
      ~MultiDataset.signal_preprocessors
      ~MultiDataset.signals
      ~MultiDataset.trials
   
   